@@ -14,7 +14,6 @@ import requests
 
 from divio_cli.utils import get_local_git_remotes
 
-from . import utils
 from .. import settings
 from ..cloud import get_divio_host
 from ..utils import (
@@ -24,8 +23,10 @@ from ..utils import (
     get_size,
     get_subprocess_env,
     is_windows,
+    needs_legacy_migration,
     pretty_size,
 )
+from . import utils
 
 
 DEFAULT_GIT_HOST = "git@git.{divio_host}"
@@ -170,20 +171,26 @@ def setup_website_containers(
             db_type=db_type,
         )()
 
-        click.secho("syncing and migrating database", fg="green")
-
-        if is_windows():
-            # interactive mode is not yet supported with docker-compose
-            # on windows. that's why we have to call it as daemon
-            # and just wait a sane time
-            check_call(docker_compose("run", "-d", "web", "start", "migrate"))
-            sleep(30)
-        else:
-            check_call(
-                docker_compose(
-                    "run", "web", "/bin/bash", "-c", "sleep 5; start migrate"
+        if needs_legacy_migration():
+            click.secho("syncing and migrating database", fg="green")
+            if is_windows():
+                # interactive mode is not yet supported with docker-compose
+                # on windows. that's why we have to call it as daemon
+                # and just wait a sane time
+                check_call(
+                    docker_compose("run", "-d", "web", "start", "migrate"),
+                )
+                sleep(30)
+            else:
+                check_call(
+                    docker_compose(
+                        "run",
+                        "web",
+                        "/bin/bash",
+                        "-c",
+                        "sleep 5; start migrate",
+                    ),
                 )
-            )
 
 
 def create_workspace(
@@ -1079,15 +1086,20 @@ def update_local_project(git_branch, client, strict=False):
         check_call(docker_compose("pull"))
         click.secho("Building local docker images", fg="green")
         check_call(docker_compose("build"))
-        click.secho("syncing and migrating database", fg="green")
-        if is_windows():
-            # interactive mode is not yet supported with docker-compose
-            # on windows. that's why we have to call it as daemon
-            # and just wait a sane time
-            check_call(docker_compose("run", "-d", "web", "start", "migrate"))
-            sleep(30)
-        else:
-            check_call(docker_compose("run", "web", "start", "migrate"))
+        if needs_legacy_migration():
+            click.secho("syncing and migrating database", fg="green")
+            if is_windows():
+                # interactive mode is not yet supported with docker-compose
+                # on windows. that's why we have to call it as daemon
+                # and just wait a sane time
+                check_call(
+                    docker_compose("run", "-d", "web", "start", "migrate"),
+                )
+                sleep(30)
+            else:
+                check_call(
+                    docker_compose("run", "web", "start", "migrate"),
+                )
 
 
 def develop_package(package, no_rebuild=False):
