@@ -1,5 +1,7 @@
 SESSION_EXPIRED = "Session expired. Please log in again."
-NETWORK_ERROR_MESSAGE = "Network error. Please check your connection and try again."
+NETWORK_ERROR_MESSAGE = (
+    "Network error. Please check your connection and try again."
+)
 AUTH_SERVER_ERROR = (
     "A problem occured while trying to authenticate with divio.com. "
     "Please try again later"
@@ -11,14 +13,18 @@ SERVER_ERROR = (
 AUTH_INVALID_TOKEN = "Login failed. Invalid token specified"
 RESOURCE_NOT_FOUND_ANONYMOUS = "Resource not found"
 RESOURCE_NOT_FOUND = "Resource not found. You are logged in as '{login}', please check if you have permissions to access the resource"
-LOGIN_SUCCESSFUL = u"Welcome to Divio Cloud. You are now logged in as {greeting}"
+LOGIN_SUCCESSFUL = (
+    u"Welcome to Divio Cloud. You are now logged in as {greeting}"
+)
 CONFIG_FILE_NOT_FOUND = u"Config file could not be not found at location: {}"
 FILE_NOT_FOUND = u"File could not be found: {}"
 INVALID_DB_SUBMITTED = (
     "The database dump you have uploaded contains an error. "
     "Please check the file 'db_upload.log' for errors and try again"
 )
-LOGIN_CHECK_SUCCESSFUL = "Authentication with server successful. You are logged in."
+LOGIN_CHECK_SUCCESSFUL = (
+    "Authentication with server successful. You are logged in."
+)
 LOGIN_CHECK_ERROR = (
     "You are currently not logged in, " "please log in using `divio login`."
 )
